Crate inf_add

Crate inf_add 

Inf add

inf_add desribes a struct and related functions which allow you to infinitely add and subtract to/from a positive number. The number is stored as a vector of u128 unsigned integers, and converted to base 10 for displaying (as such, larger numbers have larger computation cost, especially for displaying).

Structs

InfInt

Traits

AddAndCarry